==> web-8.0.2.tgz: package/lib/calendar/CalendarInp.js <==
import * as React from "react";
import { Animate } from "../animate/index";
import * as Immutable from "immutable";
import { SvgIcon } from "../my-icon/index";
import { slideOther } from "../util/autoSlideUp";
class CalendarInp extends React.PureComponent {
    constructor() {
        super(...arguments);
        this.state = {};
        this.clearValue = (e) => {
            e.stopPropagation();
            const { changeBasicState, style, curTime } = this.props;
            changeBasicState("selTimeArr", function (_state) {
                const { hour, minute, month, searson } = curTime;
                const initArr = Array.from({ length: style }).map(() => {
                    return {
                        year: "",
                        month,
                        searson,
                        day: 1,
                        hour,
                        minute,
                    };
                });
                return Immutable.fromJS(initArr);
            });
        };
        this.toggleDrop = (e) => {
            const { changeBasicState, eventId } = this.props;
            slideOther(e.nativeEvent, eventId);
            changeBasicState("expand", function (state) {
                return !state.expand;
            });
        };
    }
    render() {
        const { inpVal, placeholder, ableClear } = this.props;
        const closeIcon = ableClear ? (React.createElement(Animate, { spanWrapEle: true, animation: inpVal ? "fadeIn" : "fadeOut" },
            React.createElement("span", { className: "m-search-close", onClick: this.clearValue },
                React.createElement(SvgIcon, { className: "close" })))) : undefined;
        return (React.createElement("div", { className: "m-clalendar-inpBox", onClick: this.toggleDrop },
            React.createElement("input", { className: "s-inp calendar-inpTxt", value: inpVal, placeholder: placeholder, readOnly: true, type: "text" }),
            closeIcon,
            React.createElement("span", { className: "calendar-inp-icon" },
                React.createElement(SvgIcon, { className: "calendar" }))));
    }
}
export default CalendarInp;

==> web-9.0.0.tgz: package/lib/calendar/CalendarInp.js <==
import * as React from "react";
import { Animate } from "../animate/index";
import * as Immutable from "immutable";
import { SvgIcon } from "../my-icon/index";
import { slideOther } from "../util/autoSlideUp";
class CalendarInp extends React.PureComponent {
    constructor() {
        super(...arguments);
        this.state = {};
        this.clearValue = (e) => {
            e.stopPropagation();
            const { changeBasicState, style, curTime } = this.props;
            changeBasicState("selTimeArr", function (_state) {
                const { hour, minute, month, searson } = curTime;
                const initArr = Array.from({ length: style }).map(() => {
                    return {
                        year: "",
                        month,
                        searson,
                        day: 1,
                        hour,
                        minute,
                    };
                });
                return Immutable.fromJS(initArr);
            });
        };
        this.toggleDrop = (e) => {
            const { changeBasicState, eventId } = this.props;
            slideOther(e.nativeEvent, eventId);
            changeBasicState("expand", function (state) {
                return !state.expand;
            });
        };
    }
    render() {
        const { inpVal, placeholder, ableClear, disabled, require, matchTimeStr, field } = this.props;
        const closeIcon = ableClear && !disabled ? (React.createElement(Animate, { spanWrapEle: true, animation: inpVal ? "fadeIn" : "fadeOut" },
            React.createElement("span", { className: "m-search-close", onClick: this.clearValue },
                React.createElement(SvgIcon, { className: "close" })))) : undefined;
        const disabledName = disabled ? "disabled" : "";
        let noFill = matchTimeStr ? matchTimeStr(field, inpVal) : require && !disabled && ableClear && !inpVal;
        const requireName = noFill ? "no-fill" : "";
        return (React.createElement("div", { className: `m-clalendar-inpBox ${disabledName} ${requireName}`, onClick: disabled ? undefined : this.toggleDrop },
            React.createElement("input", { className: "s-inp calendar-inpTxt", value: inpVal, disabled: disabled, placeholder: placeholder, readOnly: true, type: "text" }),
            closeIcon,
            React.createElement("span", { className: "calendar-inp-icon" },
                React.createElement(SvgIcon, { className: "calendar" }))));
    }
}
export default CalendarInp;
